function TEB_theo=TEB_theorique(EbitN0_dB,M,method_mod)
% Cette fonction permet de tracer le TEB theorique en fonction d'un vecteur de SNR EbitN0_dB pour differentes modulations
%
% INPUTS :
% EbitN0_dB : vecteur de SNR en dB
% M : valence
% method_mod : nom de la modulation (BdB, ASK, PSK ou QAM)
%
% OUTPUTS :
% TEB_theo : vecteur contenant les TEB theoriques associes

EbitN0=10.^(EbitN0_dB/10);

if nargin<3
    method_mod='BdB';
end

switch method_mod
    case 'BdB'
        TEB_theo=(M-1)/(M*log2(M)) * erfc(sqrt(EbitN0 * 3 * log2(M) /(M^2-1)));
    case 'ASK'
        TEB_theo=(M-1)/(M*log2(M)) * erfc(sqrt(3*log2(M)/(M^2-1)*EbitN0));
    case 'PSK'
        if M==2
            TEB_theo=(M-1)/(M*log2(M)) * erfc(sqrt(3*log2(M)/(M^2-1)*EbitN0));
        else
            TEB_theo = (1/log2(M)) * erfc(sqrt(log2(M)*EbitN0)*sin(pi/M));
        end
    case 'QAM'
        M=sqrt(M);
        TEB_theo = (M-1)/(M*log2(M)) * erfc(sqrt(3*log2(M)/(M^2-1)*EbitN0));
    otherwise
        error('Modulation non valide');
end

