function compute_dsp(x,Fs,method_dsp)
% Cette fonction estime la densite spectrale de puissance du signal
% x echantillonne a la frequence d'echantillonnage Fs
%
% INPUTS :
% x : signal d'entree
% Fs : frequence d'echantillonnage
% method_dsp : lin (lineaire) ou log (decibels)
%
% OUTPUTS (pas necessaires car seuls les traces suffisent pour le TP) : 
% DSP : densite spectrale de puissance estimee
% f : vecteur frequence associe

if nargin<3
    method_dsp='log'
end

N=length(x);

N_T=10*Fs;
t=1:N_T;
nfft=4096;

K=1;
DSP=abs(fft(x(t),nfft)).^2;
while max(t)+N_T/2<N
    t=t+N_T/2;
    DSP=DSP+abs(fft(x(t),nfft)).^2;
    K=K+1;
end


DSP=fftshift(DSP/(K*N_T*Fs));

f=(0:nfft-1)'*Fs/nfft;
f(f>=Fs/2)=f(f>=Fs/2)-Fs;
f=fftshift(f);


switch method_dsp
    case 'log'
        figure
        plot(f,10*log10(DSP))
        title('Densite spectrale de puissance 10 log_{10} \Gamma_x(f)')
        ylabel('Decibels (dB)')
        xlabel('Frequence (Hz)')
    case 'lin'
        figure
        plot(f,DSP)
        title('Densite spectrale de puissance \Gamma_x(f)')
        ylabel('')
        xlabel('Frequence (Hz)')
    otherwise
        error('Probleme trace DSP')
end







