function [dico_sym,dico_dec]=dictionnaire(M,method_mod)
% Cette fonction renvoie les symboles et les representations decimales associees pour plusieurs modulations
%
% INPUTS : 
% M : valence
% method_mod : nom de la modulation (BdB, ASK, PSK ou QAM)
%
% OUTPUTS :
% dico_sym : vecteur contenant les M symboles (ex : -1 et 1)
% dico_dec : code binaire associe a chacun des symboles (ex : 3 pour 11, 2 pour 10 etc...)


if nargin<2
    method_mod='BdB';
end


switch method_mod
    
    case 'BdB'       
        switch M
            case 2
                dico_sym=[-1;1];
                dico_dec=[0;1];
            case 4
                dico_sym=[-3;-1;3;1];
                dico_dec=[0;1;2;3];
            case 8
                dico_sym=[-7; -5 ;-3; -1 ;1 ;3 ;5 ;7];
                dico_dec=[0 ;1 ;3 ;2; 6; 7; 5 ;4];
            otherwise
                error('Valeur de M invalide');
        end
        
    case 'ASK'        
        switch M            
            case 2
                dico_sym=[-1; 1];
                dico_dec=[0 ;1];
            case 4
                dico_sym=[-3 ;-1; 1 ;3];
                dico_dec=[0 ;1 ;3 ;2];
            case 8
                dico_sym=[-7; -5 ;-3; -1 ;1 ;3 ;5 ;7];
                dico_dec=[0 ;1 ;3 ;2; 6; 7; 5 ;4];
            otherwise
                error('Valeur de M invalide');
        end
        
    case 'PSK'        
        switch M            
            case 2
                dico_sym=[-1; 1];
                dico_dec=[0 ;1];
            case 4
                dico_sym=exp(sqrt(-1)*pi/4 *[-3 ;-1; 1 ;3]);
                dico_dec=[0 ;2 ;3 ;1];
            case 8
                dico_sym=exp(sqrt(-1)*pi/8 *[-7 ;-5 ;-3 ;-1 ;1 ;3 ;5 ;7]);
                dico_dec=[1 ;0; 4; 5; 7; 6; 2; 3];
            otherwise
                error('Valeur de M invalide');
        end
        
    case 'QAM'        
        switch M            
            case 4
                dico_sym=[-1-sqrt(-1) ;-1+sqrt(-1); 1+sqrt(-1); 1-sqrt(-1)];
                dico_dec=[0; 1 ;3 ;2];
            case 16
                dico_sym=[-3-3*sqrt(-1) ;-3-sqrt(-1) ;-3+3*sqrt(-1) ;-3+sqrt(-1);...
                    -1-3*sqrt(-1); -1-sqrt(-1); -1+3*sqrt(-1); -1+sqrt(-1);...
                    3-3*sqrt(-1); 3-sqrt(-1); 3+3*sqrt(-1); 3+sqrt(-1);...
                    1-3*sqrt(-1); 1-sqrt(-1); 1+3*sqrt(-1); 1+sqrt(-1)];
                dico_dec=[0; 1; 2 ;3 ;4 ;5; 6; 7 ;8 ;9 ;10 ;11 ;12 ;13 ;14 ;15];
            otherwise
                error('Valeur de M invalide');
        end
        
    otherwise
        error('Modulation non valide');      
    
end




